## PDFMathTranslate

PDF 科学論文の翻訳とバイリンガル比較。 - 📊 数式、チャート、目次、注釈を保持 _（[プレビュー](#プレビュー)）_。 - 🌐 [複数言語](https://pdf2zh-next.com/supported_languages.html) をサポートし、多様な [翻訳サービス](https://pdf2zh-next.com/advanced/Documentation-of-Translation-Services.html) に対応。 - 🤖 [コマンドラインツール](https://pdf2zh-next.com/getting-started/USAGE_commandline.html)、[インタラクティブユーザーインターフェース](https://pdf2zh-next.com/getting-started/USAGE_webui.html)、[Docker](https://pdf2zh-next.com/getting-started/INSTALLATION_docker.html) を提供 > [!WARNING] > > このプロジェクトは「現状有姿」で AGPL v3 ライセンスの下で提供されており、プログラムの品質や性能について一切の保証はありません。**プログラムの品質や性能に関する全てのリスクはあなたが負担します。** プログラムに欠陥が見つかった場合、必要なサービス、修理、または修正にかかる費用は全てあなたの責任となります。 > > リソースが限られているため、当方はいかなる形式の使用支援や問題解決も提供しません。関連する issue は直接クローズされます！（このプロジェクトのドキュメント改善のために PR を提出することは歓迎します。バグや友好的な issue はこれに影響されません。） 詳細な貢献方法については、[貢献ガイド](https://pdf2zh-next.com/community/Contribution-Guide.html)をご覧ください。

## 更新情報

- [2025年6月4日] プロジェクト名が変更され、[PDFMathTranslate/PDFMathTranslate-next](https://github.com/PDFMathTranslate/PDFMathTranslate-next) に移動しました（by [@awwaawwa](https://github.com/awwaawwa)） - [2025年3月3日] 新しいバックエンド [BabelDOC](https://github.com/funstory-ai/BabelDOC) の実験的サポートが追加され、WebUI が実験的オプションとして利用可能になりました（by [@awwaawwa](https://github.com/awwaawwa)） - [2025年2月22日] リリース CI が改善され、Windows-amd64 用の exe ファイルが適切にパッケージ化されました（by [@awwaawwa](https://github.com/awwaawwa)） - [2024年12月24日] 翻訳ツールが [Xinference](https://github.com/xorbitsai/inference) 上のローカルモデルをサポートするようになりました（by [@imClumsyPanda](https://github.com/imClumsyPanda)） - [2024年12月19日] `-cp` を使用して非 PDF/A ドキュメントがサポートされるようになりました（by [@reycn](https://github.com/reycn)） - [2024年12月13日] バックエンドの追加サポートが実装されました（by [@YadominJinta](https://github.com/YadominJinta)） - [2024年12月10日] 翻訳ツールが Azure 上の OpenAI モデルをサポートするようになりました（by [@yidasanqian](https://github.com/yidasanqian)）

## プレビュー

## オンラインサービス 🌟

> [!NOTE] > > pdf2zh 2.0 は現在オンラインデモを提供していません 以下のデモのいずれかを使用して、アプリケーションをお試しください： - [v1.x パブリック無料サービス](https://pdf2zh.com/) インストール不要でオンライン利用可能 _(推奨)_ - [Immersive Translate - BabelDOC](https://app.immersivetranslate.com/babel-doc/) 月間1000ページ無料 _(推奨)_ デモの計算リソースは限られているため、乱用しないようご注意ください。

## インストールと使い方

### インストール 1. [**Windows EXE**](https://pdf2zh-next.com/getting-started/INSTALLATION_winexe.html) Windows 用におすすめ 2. [**Docker**](https://pdf2zh-next.com/getting-started/INSTALLATION_docker.html) Linux 用におすすめ 3. [**uv** (Python パッケージマネージャー)](https://pdf2zh-next.com/getting-started/INSTALLATION_uv.html) macOS 用におすすめ --- ### 使い方 1. [**WebUI** を使用する](https://pdf2zh-next.com/getting-started/USAGE_webui.html) 2. [**Zotero プラグイン** を使用する](https://github.com/guaguastandup/zotero-pdf2zh)（サードパーティ製プログラム） 3. [**コマンドライン** を使用する](https://pdf2zh-next.com/getting-started/USAGE_commandline.html) 異なるユースケースに対応するため、当プログラムには複数の使用方法を用意しています。詳細については[このページ](./getting-started/getting-started.md)をご覧ください。

## 高度なオプション

詳細な説明については、各オプションの完全なリストが記載されている[高度な使い方](https://pdf2zh-next.com/advanced/advanced.html)のドキュメントを参照してください。

## 二次開発（API）

> [!NOTE] > > 現在、関連するドキュメントは提供されていません。後日追加されますので、しばらくお待ちください。

## 言語コード

必要な言語に翻訳するためのコードがわからない場合は、[このドキュメント](https://pdf2zh-next.com/advanced/Language-Codes.html)を確認してください。

## 謝辞

    - [Immersive Translation](https://immersivetranslate.com) は、このプロジェクトの積極的な貢献者に対して月額プロ会員の引き換えコードを提供しています。詳細はこちらをご覧ください：[CONTRIBUTOR_REWARD.md](https://github.com/funstory-ai/BabelDOC/blob/main/docs/CONTRIBUTOR_REWARD.md)

    - [SiliconFlow](https://siliconflow.cn) は、このプロジェクトに対して大規模言語モデル（LLM）を活用した無料翻訳サービスを提供しています。

    - 1.x バージョン：[Byaidu/PDFMathTranslate](https://github.com/Byaidu/PDFMathTranslate)

    - バックエンド：[BabelDOC](https://github.com/funstory-ai/BabelDOC)

    - PDF ライブラリ：[PyMuPDF](https://github.com/pymupdf/PyMuPDF)

    - PDF 解析：[Pdfminer.six](https://github.com/pdfminer/pdfminer.six)

    - PDF プレビュー：[Gradio PDF](https://github.com/freddyaboulton/gradio-pdf)

    - レイアウト解析：[DocLayout-YOLO](https://github.com/opendatalab/DocLayout-YOLO)

    - PDF 標準：[PDF Explained](https://zxyle.github.io/PDF-Explained/)、[PDF Cheat Sheets](https://pdfa.org/resource/pdf-cheat-sheets/)

    - 多言語フォント：[BabelDOC-Assets](https://github.com/funstory-ai/BabelDOC-Assets) をご覧ください

    - [Asynchronize](https://github.com/multimeric/Asynchronize/tree/master?tab=readme-ov-file)

    - [Rich logging with multiprocessing](https://github.com/SebastianGrans/Rich-multiprocess-logging/tree/main)

    - Weblate を使用したドキュメントの国際化：[Weblate](https://weblate.org/)

## コードを提出する前に

私たちは、pdf2zh をより良くするために貢献者の積極的な参加を歓迎します。コードを提出する準備が整う前に、[行動規範](https://pdf2zh-next.com/community/CODE_OF_CONDUCT.html) と [貢献ガイド](https://pdf2zh-next.com/community/Contribution-Guide.html) を参照してください。

## 貢献者

![Alt](https://repobeats.axiom.co/api/embed/45529651750579e099960950f757449a410477ad.svg "Repobeats analytics image")

## スター履歴

###### このページの一部のコンテンツはGPTによって翻訳されており、エラーが含まれている可能性があります。